@@ -1,6 +1,6 @@
 package Ubic::Service::Memcached;
 BEGIN {
-  $Ubic::Service::Memcached::VERSION = '1.01';
+  $Ubic::Service::Memcached::VERSION = '1.02';
 }
 
 use strict;
@@ -24,6 +24,7 @@ sub new {
         pidfile => { type => SCALAR },
         maxsize => { type => SCALAR, regex => qr/^\d+$/, default => 640 },
         verbose => { type => SCALAR, optional => 1 },
+        max_connections => { type => SCALAR, optional => 1 },
         logfile => { type => SCALAR, optional => 1 },
         ubic_log => { type => SCALAR, optional => 1 },
         user => { type => SCALAR, default => 'root' },
@@ -40,6 +41,7 @@ sub start_impl {
     push @$params, "-u $self->{user}" if $self->{user} eq 'root';
     push @$params, "-p $self->{port}";
     push @$params, "-m $self->{maxsize}";
+    push @$params, "-c $self->{max_connections}" if defined $self->{max_connections};
     my $verbose = $self->{verbose};
     if (defined($verbose) && $verbose == 1) {
         push @$params, "-v";
@@ -136,7 +138,7 @@ Ubic::Service::Memcached - memcached as ubic service
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -194,6 +196,10 @@ If specified, memcached will be configured to write logs to given file.
 
 Optional log with ubic-specific messages.
 
+=item I<max_connections>
+
+Number of max simultaneous connections (C<-c> memcached option).
+
 =item I<user>
 
 =item I<group>
@@ -210,7 +216,7 @@ Vyacheslav Matyukhin <me@berekuk.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yandex LLC.
+This software is copyright (c) 2011 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
